@@ -9,7 +9,7 @@ overallcovp1<-function(tfix=2.0,tfix0=1.0,taur=5,u=c(1/taur,1/taur),ut=c(taur/2,
                     rate41=rate21,rate51=rate51,ratec1=c(0.5,0.6),
                     rate10=rate11,rate20=rate10,rate30=rate31,
                     rate40=rate20,rate50=rate20,ratec0=ratec1,
-                    tchange=c(0,1),type1=1,type0=1,
+                    tchange=c(0,1),type1=1,type0=1,rp21=0.5,rp20=0.5,
                     eps=1.0e-2,veps=1.0e-2,beta=0,beta0=0){
   ##tfix: the time point where the overall log hazard ratio beta is calculated
   ##tfix0: the time point where the overall log hazard ratio beta0 is calculated
@@ -23,6 +23,7 @@ overallcovp1<-function(tfix=2.0,tfix0=1.0,taur=5,u=c(1/taur,1/taur),ut=c(taur/2,
   ##rate30: hazard for treatment discontinuation for the control group
   ##ratec0: hazard for loss to follow-up for the control group
   ##tchange: points at which hazard changes
+  ##rp21, rp20 re-randomization prob for the tx and contl groups
 
   ######Part A################################################################################
   #ratemax<-max(c(max(c(rate21,rate20)),max(c(rate11+rate31,rate10+rate30)),max(c(ratec1,ratec0)),max(abs(c(rate11+rate31-rate21,rate10+rate30-rate20)))))
@@ -74,11 +75,11 @@ overallcovp1<-function(tfix=2.0,tfix0=1.0,taur=5,u=c(1/taur,1/taur),ut=c(taur/2,
     BigK1<-pwecxpwuforvar(tfix=tfix,t=atsupp,taur=taur,u=u,ut=ut,
               rate1=rate11,rate2=rate21,rate3=rate31,
               rate4=rate41,rate5=rate51,ratec=ratec1,
-              tchange=tchange,type=type1,eps=eps)
+              tchange=tchange,type=type1,rp2=rp21,eps=eps)
     BigK0<-pwecxpwuforvar(tfix=tfix,t=atsupp,taur=taur,u=u,ut=ut,
               rate1=rate10,rate2=rate20,rate3=rate30,
               rate4=rate40,rate5=rate50,ratec=ratec0,
-              tchange=tchange,type=type0,eps=eps)
+              tchange=tchange,type=type0,rp2=rp20,eps=eps)
     dk1<-BigK1$f0[-1]-BigK1$f0[-nsupp]
     dk0<-BigK0$f0[-1]-BigK0$f0[-nsupp]
     ###12/22/2016
@@ -94,16 +95,16 @@ overallcovp1<-function(tfix=2.0,tfix0=1.0,taur=5,u=c(1/taur,1/taur),ut=c(taur/2,
 
 
     ST11<-pwecx(t=tk1,rate1=rate11,rate2=rate21,rate3=rate31,
-          rate4=rate41,rate5=rate51,tchange=tchange,type=type1,eps=eps)$surv
+          rate4=rate41,rate5=rate51,tchange=tchange,type=type1,rp2=rp21,eps=eps)$surv
     ST10<-pwecx(t=tk1,rate1=rate10,rate2=rate20,rate3=rate30,
-          rate4=rate40,rate5=rate50,tchange=tchange,type=type0,eps=eps)$surv
+          rate4=rate40,rate5=rate50,tchange=tchange,type=type0,rp2=rp20,eps=eps)$surv
     SC11<-pwe(t=tk1,rate=ratec1,tchange=tchange)$surv
     SC10<-pwe(t=tk1,rate=ratec0,tchange=tchange)$surv
 
     ST01<-pwecx(t=tk0,rate1=rate11,rate2=rate21,rate3=rate31,
-          rate4=rate41,rate5=rate51,tchange=tchange,type=type1,eps=eps)$surv
+          rate4=rate41,rate5=rate51,tchange=tchange,type=type1,rp2=rp21,eps=eps)$surv
     ST00<-pwecx(t=tk0,rate1=rate10,rate2=rate20,rate3=rate30,
-          rate4=rate40,rate5=rate50,tchange=tchange,type=type0,eps=eps)$surv
+          rate4=rate40,rate5=rate50,tchange=tchange,type=type0,rp2=rp20,eps=eps)$surv
     SC01<-pwe(t=tk0,rate=ratec1,tchange=tchange)$surv
     SC00<-pwe(t=tk0,rate=ratec0,tchange=tchange)$surv
 
@@ -120,14 +121,14 @@ overallcovp1<-function(tfix=2.0,tfix0=1.0,taur=5,u=c(1/taur,1/taur),ut=c(taur/2,
         rate41=rate41,rate51=rate51,ratec1=ratec1,
         rate10=rate10,rate20=rate20,rate30=rate30,
         rate40=rate40,rate50=rate50,ratec0=ratec0,
-        tchange=tchange,type1=type1,type0=type0,
+        tchange=tchange,type1=type1,type0=type0,rp21=rp21,rp20=rp20,
         eps=eps,veps=veps,beta=beta0)
     ak0<-innervar(t=tk0-(tfix-tfix0),taur=taur,u=u,ut=ut,pi1=pi1,
         rate11=rate11,rate21=rate21,rate31=rate31,
         rate41=rate41,rate51=rate51,ratec1=ratec1,
         rate10=rate10,rate20=rate20,rate30=rate30,
         rate40=rate40,rate50=rate50,ratec0=ratec0,
-        tchange=tchange,type1=type1,type0=type0,
+        tchange=tchange,type1=type1,type0=type0,rp21=rp21,rp20=rp20,
         eps=eps,veps=veps,beta=beta0)
 
     covbeta1<-pi1*sum(q1bs*(1-q1bs)*ak1$qf1*dk1)-(1-pi1)*sum(q0bs^2*ak0$qf1*dk0)
